@@ -23,7 +23,7 @@ def GenCredentialsProfile4Account(accountid):
 def GenSteampipeConnection4Account(accountid):
     sectionname=orgprefix+'_'+accountid
     if sectionname not in cf.sections():
-        cf.add_section(sectionname)    
+        cf.add_section(sectionname)
     cf.set(sectionname,'plugin','"aws"')
     cf.set(sectionname,'profile','"'+orgprefix+'_'+accountid+'"')
     cf.set(sectionname,'regions','["'+'","'.join(session.get_available_regions('s3',session.get_partition_for_region(session.region_name)))+'"]')
@@ -44,10 +44,20 @@ def GenSteampipeConnection4OU(ouid,isroot):
             oudict[ouname]=[]
     
     #记录OU下Account list
+    ouaccountlist = []
     response = client.list_children(
         ParentId=ouid,
         ChildType='ACCOUNT'
     )
+    if 'NextToken' in response:
+        while 'NextToken' in response:
+            ouaccountlist.extend(response['Children'])
+            response = client.list_children(
+                ParentId=ouid,
+                ChildType='ACCOUNT',
+                NextToken = response['NextToken']
+            )
+    ouaccountlist.extend(response['Children'])
 
     for accountel in response['Children']:
         oudict[ouname].append(accountel['Id'])
@@ -57,11 +67,21 @@ def GenSteampipeConnection4OU(ouid,isroot):
             oudict[pou].append(accountel['Id'])
 
     #遍历OU Tree
+    suboulist = []
     response = client.list_children(
         ParentId=ouid,
         ChildType='ORGANIZATIONAL_UNIT',
     )
-    
+    if 'NextToken' in response:
+        while 'NextToken' in response:
+            suboulist.append(response['Children'])
+            response = client.list_children(
+                ParentId=ouid,
+                ChildType='ORGANIZATIONAL_UNIT',
+                NextToken = response['NextToken']
+            )
+    suboulist.append(response['Children'])
+
     if len(response['Children'])>0 and not isroot:
         parentlist.append(ouname+'_T')
     for ouel in response['Children']:
@@ -79,6 +99,8 @@ def main():
     global client
     global oudict
     global parentlist
+    global createawsconfigprofile
+    global steampipeinipath
 
     # 创建 ArgumentParser 对象
     parser = argparse.ArgumentParser(description='Generate steampipe connection file(.spc) for accounts and OUs in specified AWS organization.'+ \
@@ -112,15 +134,28 @@ def main():
         rolename='OrganizationAccountAccessRole'
 
     createawsconfigprofile=args.createawsconfigprofile
+    cf = configparser.ConfigParser()
+
+    #~/.steampipe/config/<connection file>
+    #读取steampipe connection配置文件
+    steampipeinipath = os.path.join(os.path.expanduser('~'), '.steampipe/config/aws-'+orgprefix+'.ini')
+    steampipespcpath = os.path.join(os.path.expanduser('~'), '.steampipe/config/aws-'+orgprefix+'.spc')
 
     # Init boto3 client
-    cf = configparser.ConfigParser()
     session=boto3.session.Session()
     client = boto3.client('organizations')
 
     #遍历Organizatoin accounts
-    response = client.list_accounts()
-
+    accountlist=[]
+    response = client.list_accounts(
+    )
+    if 'NextToken' in response:
+        while 'NextToken' in response:
+            accountlist.extend(response['Accounts'])
+            response = client.list_accounts(
+                NextToken = response['NextToken']
+            )
+    accountlist.extend(response['Accounts'])
     #~/.aws/config profiles
     if createawsconfigprofile:
         #读取aws config配置文件
@@ -128,7 +163,7 @@ def main():
         cf.read(awsconfigpath)
 
         #生成aws config配置文件条目
-        for accountel in response['Accounts']:
+        for accountel in accountlist:
             GenConfigProfile4Account(accountel['Id'])
         with open(awsconfigpath, 'w') as configfile:
             cf.write(configfile)
@@ -143,20 +178,15 @@ def main():
     cf.set(orgprefix+'_base','credential_process','aws-vault exec -j '+sourceprofile+' --region='+session.region_name)
 
     #生成aws credentials配置文件条目
-    for accountel in response['Accounts']:
+    for accountel in accountlist:
         GenCredentialsProfile4Account(accountel['Id'])
     with open(awscredpath, 'w') as configfile:
         cf.write(configfile)
     cf = configparser.ConfigParser()
 
-    #~/.steampipe/config/<connection file>
-    #读取steampipe connection配置文件
-    steampipeinipath = os.path.join(os.path.expanduser('~'), '.steampipe/config/aws-'+orgprefix+'.ini')
-    steampipespcpath = os.path.join(os.path.expanduser('~'), '.steampipe/config/aws-'+orgprefix+'.spc')
-    cf.read(steampipeinipath)
-
     #为每个account生成steampipe connection config配置文件条目
-    for accountel in response['Accounts']:
+    cf.read(steampipeinipath)
+    for accountel in accountlist:
         GenSteampipeConnection4Account(accountel['Id'])
 
     #为每个OU生成steampipe connection config配置文件条目
@@ -164,15 +194,28 @@ def main():
     oudict={}
     parentlist=[]
 
+    #遍历Organizatoin accounts
     response = client.list_roots(
     )
-    for rootel in response['Roots']:
+    rootlist = []
+    if 'NextToken' in response:
+        while 'NextToken' in response:
+            rootlist.extend(response['Roots'])
+            response = client.list_roots(
+                NextToken = response['NextToken']
+            )
+    rootlist.extend(response['Roots'])
+    for rootel in rootlist:
         GenSteampipeConnection4OU(rootel['Id'],True)
-        
+
     #为整个Organization生成steampipe connection config配置文件条目
     for ouname in oudict:
         if len(oudict[ouname])>0:
-            sectionname=orgprefix+'_'+re.sub(r'^r\-','',ouname)
+            #处理ouname中不符合connection配置要求的字符
+            sectionname=re.sub(r'^r\-','',ouname)
+            sectionname=re.sub(r'[ @\-]','_',sectionname)
+
+            sectionname=orgprefix+'_'+sectionname
             if sectionname not in cf.sections():
                 cf.add_section(sectionname)
             cf.set(sectionname,'type','"aggregator"')
